@@ -1,5 +1,13 @@
 #if 0
 
+N_("Pesce alla sale")
+N_("It's an easy but tasty way to prepare fish.")
+N_("Despite all the salt, the result isn't salty but soft and nice.")
+N_("Preheat the oven.")
+N_("Stuff the fish with a mix of lemon and dill.")
+N_("Combine the salt and eggs. Spread this mix over the fish.")
+N_("Bake it 20' - 25'  or until the crust is brown. ")
+N_("Serve it with plain rice.")
 N_("Crispy olives")
 N_("These olives in cheese dough are quick and easy to make and are great as a side dish or snack.")
 N_("[image:1]Grate the cheese.")
@@ -29,6 +37,20 @@ N_("The pizza cheese should be below the toppings. This way the good ingredients
 N_("If you use wet toppings like pineapples or mozzarella, dry them in a sieve before.")
 N_("Don't put too much on the pizza.")
 N_("Put the pizza with the shovel in the oven and bake it till it is brown. Duration is depending on oven temperature.")
+N_("Pizza Dough")
+N_("Pizza Dough")
+N_("Pizza Dough")
+N_("Pizza Dough")
+N_("Pizza Dough")
+N_("Pizza Sauce")
+N_("Pizza Sauce")
+N_("Pizza Sauce")
+N_("Pizza Sauce")
+N_("Pizza Sauce")
+N_("Pizza Sauce")
+N_("Pizza Sauce")
+N_("Pizza Sauce")
+N_("Pizza Sauce")
 N_("Quinoa Salad")
 N_("Yummy salad that goes with just about anything.")
 N_("Cook it like rice so bring quinoa and water to a boil  Reduce heat to medium-low, cover, and simmer until quinoa is tender and water has been absorbed, 10 to 15 minutes. Set aside to cool, this is important otherwise things get sticky ")
@@ -107,6 +129,19 @@ N_("[timer:00:30:00,Bake]Bake for 30 minutes at [temperature:200C].")
 N_("[image:7]Use the milk, sugar and pudding to cook vanilla pudding and let it cool down while stirring it frequently. Slowly add spoonfuls of the butter, which should be at room temperature.")
 N_("[image:8]Spread the butter cream on the cooled cake.")
 N_("[image:9]Melt the chocolate frosting in a hot water bath and sprinkle it on top.")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Toppings")
+N_("Toppings")
+N_("Toppings")
+N_("Toppings")
+N_("Toppings")
 N_("Gingered Carrot Soup")
 N_("A nutritious vegan soup that can be made relatively quickly")
 N_("Place carrots in large saucepan with water, cover, bring to a boil. Lower heat, simmer until very tender (10-15 minutes). While carrots are cooking, saute in olive oil all the onions, 5 minutes, then add garlic, ginger, salt, and spices. When all is well mingled, stir in lemon juice. Use food processor or blender to puree everything together (including all the toasted cashews). If you like a more textured soup, only half puree.")
@@ -126,6 +161,11 @@ N_("(With Chocolate) Mix melted 75% vegan chocolate")
 N_("(With Cocoa Butter) Melt the cocoa butter [image:1]")
 N_("(With Cocoa Butter) Mix the hazelnuts milk, melted cocoa butter and the cocoa powder until the mass gets uniform [image:2]")
 N_("Enjoy [image:3]")
+N_("Cocoa Butter Version")
+N_("Cocoa Butter Version")
+N_("Cocoa Butter Version")
+N_("Base")
+N_("Chocolate Version")
 N_("Hazelnuts Milk")
 N_("Simple Hazelnuts Milk with a smooth, naturally sweet flavor.")
 N_("Preheat the over at [temperature:200C]")
@@ -201,6 +241,13 @@ N_("Spread olive oil in a 10-inch cast iron skillet or round cake pan and place
 N_("Rub the dough ball around and flip it a couple times until it is completely coated in oil and the oil completely coats the bottom and sides of the pan. Cover in plastic, and let it sit for another couple of hours without touching it.")
 N_("The dough should have spread on it own (takes about 2 hours). Lift the sides of the dough to let big air bubbles out.")
 N_("Put in the oven at [temperature:280C]. (or as hot as your oven goes) for about 15 minutes. Peek underneath and if your pizza is a little pale, you can finish on the stovetop directly over medium heat until it is as dark and crisp as you like it.")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Toppings")
+N_("Toppings")
+N_("Toppings")
 N_("Pineapple Upside Down Cake with Hot Buttered Rum Sauce")
 N_("This is a delicious, boozy update on a classic cake. The combination of rum and pineapple gives it a distinctively Caribbean flavor.")
 N_("Preheat the oven to [temperature:175C] (gas mark 4).")
@@ -214,6 +261,20 @@ N_("[timer:00:40:00,Bake]Poor the cake mixture into the cake tin and bake for ar
 N_("[timer:00:05:00,Cool]Leave the cake to cool for 5 minutes, then turn out on to a rack to cool completely.")
 N_("When it's time to eat, make the sauce: combine the muscovado sugar and cream in a saucepan and heat until the sugar has dissolved. Add the rum and simmer until it has thickened a little, then add the butter and let it melt into the sauce.")
 N_("Pour the hot sauce over the cake and serve.")
+N_("Sauce")
+N_("Sauce")
+N_("Sauce")
+N_("Sauce")
+N_("Cake")
+N_("Cake")
+N_("Cake")
+N_("Cake")
+N_("Cake")
+N_("Cake")
+N_("Cake")
+N_("Cake")
+N_("Cake")
+N_("Cake")
 N_("Pizzaburger")
 N_("Tomato dough with hamburger and cheese topping")
 N_("Dissolve yeast in warm water. Let stand for 2 minutes.")
@@ -250,6 +311,21 @@ N_("[image:10]Pour the contents of the bowl over the vegetables so all of the pi
 N_("[image:11]Decorate with extra cheese and linseeds for extra sazz.")
 N_("[timer:00:35:00,Bake]Bake the pie in the oven for 35 minutes.")
 N_("[image:1]Enjoy!")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Contents")
+N_("Contents")
+N_("Contents")
+N_("Contents")
+N_("Contents")
+N_("Contents")
+N_("Contents")
+N_("Contents")
+N_("Contents")
+N_("Contents")
 N_("Rosemary Scalloped Potatoes")
 N_("A holiday twist on a classic American comfort food dish. Easy to make and sure to please.")
 N_("Substitutions and conversions:")
@@ -310,6 +386,24 @@ N_("Add the ingredients matching the variation you chose, preferably sliced or d
 N_("Pour the batter in a loaf tin.")
 N_("[timer:00:40:00,Bake]Put in the oven at [temperature:180C] for 40 minutes.")
 N_("[image:1]Serve cold, cut in slices or cubes that people will get with a toothpick.")
+N_("Cake aux lardons")
+N_("Cake aux lardons")
+N_("Cake aux lardons")
+N_("Cake aux lardons")
+N_("Batter")
+N_("Batter")
+N_("Batter")
+N_("Batter")
+N_("Cake au thon et à la tomate")
+N_("Cake au thon et à la tomate")
+N_("Cake chèvre-épinards")
+N_("Cake chèvre-épinards")
+N_("Cake noix-chorizo")
+N_("Cake noix-chorizo")
+N_("Cake noix-chorizo")
+N_("Cake jambon-champignons")
+N_("Cake jambon-champignons")
+N_("Cake jambon-champignons")
 N_("Spanish Omelet")
 N_("Traditional Spanish Omelet, also known as \"Tortilla de Patata\"")
 N_("[image:0]Put a bit of oil in a pan and cover the surface with sliced onions.")
