@@ -28,7 +28,8 @@
 #endif
 
 #include "gr-recipe-importer.h"
-#include "gr-images.h"
+#include "gr-app.h"
+#include "gr-image.h"
 #include "gr-chef.h"
 #include "gr-recipe.h"
 #include "gr-recipe-store.h"
@@ -280,7 +281,7 @@ static gboolean
 import_recipe (GrRecipeImporter *importer)
 {
         GrRecipeStore *store;
-        g_autoptr(GArray) images = NULL;
+        g_autoptr(GPtrArray) images = NULL;
         g_autoptr(GrRecipe) recipe = NULL;
         g_autoptr(GError) error = NULL;
         g_autofree char *id = NULL;
@@ -288,11 +289,14 @@ import_recipe (GrRecipeImporter *importer)
 
         store = gr_recipe_store_get ();
 
+        author = (const char *)g_hash_table_lookup (importer->chef_id_map, importer->recipe_author);
+        id = generate_id ("R_", importer->recipe_name, "_by_", author, NULL);
+
         images = gr_image_array_new ();
         if (importer->recipe_paths) {
                 int i;
                 for (i = 0; importer->recipe_paths[i]; i++) {
-                        GrImage ri;
+                        GrImage *ri;
                         char *new_path;
 
                         if (!copy_image (importer, importer->recipe_paths[i], &new_path, &error)) {
@@ -300,14 +304,12 @@ import_recipe (GrRecipeImporter *importer)
                                 return FALSE;
                         }
 
-                        ri.path = new_path;
-                        g_array_append_val (images, ri);
+                        ri = gr_image_new (gr_app_get_soup_session (GR_APP (g_application_get_default ())), id, new_path);
+
+                        g_ptr_array_add (images, ri);
                 }
         }
 
-        author = (const char *)g_hash_table_lookup (importer->chef_id_map, importer->recipe_author);
-        id = generate_id ("R_", importer->recipe_name, "_by_", author, NULL);
-
         recipe = gr_recipe_new ();
         g_object_set (recipe,
                       "id", id,
@@ -464,7 +466,9 @@ next:
         importer->recipe_instructions = key_file_get_string (importer->recipes_keyfile, id, "Instructions");
         importer->recipe_notes = key_file_get_string (importer->recipes_keyfile, id, "Notes");
         importer->recipe_serves = g_key_file_get_integer (importer->recipes_keyfile, id, "Serves", &error);
+        handle_or_clear_error (error);
         importer->recipe_spiciness = g_key_file_get_integer (importer->recipes_keyfile, id, "Spiciness", &error);
+        handle_or_clear_error (error);
         importer->recipe_default_image = g_key_file_get_integer (importer->recipes_keyfile, id, "DefaultImage", &error);
         handle_or_clear_error (error);
         importer->recipe_diets = g_key_file_get_integer (importer->recipes_keyfile, id, "Diets", &error);
