@@ -31,6 +31,7 @@
 #include "gr-settings.h"
 #include "gr-utils.h"
 #include "gr-ingredients-list.h"
+#include "gr-ingredient.h"
 #include "gr-image.h"
 #include "gr-app.h"
 
@@ -974,13 +975,14 @@ set_modified_request (SoupMessage *msg,
                                   NULL,
                                   NULL);
 
-        g_file_info_get_modification_time (info, &tv);
-        mtime = g_date_time_new_from_timeval_utc (&tv);
-        mod_date = g_date_time_format (mtime, "%a, %d %b %Y %H:%M:%S %Z");
-        soup_message_headers_append (msg->request_headers, "If-Modified-Since", mod_date);
+        if (info) {
+                g_file_info_get_modification_time (info, &tv);
+                mtime = g_date_time_new_from_timeval_utc (&tv);
+                mod_date = g_date_time_format (mtime, "%a, %d %b %Y %H:%M:%S %Z");
+                soup_message_headers_append (msg->request_headers, "If-Modified-Since", mod_date);
+        }
 }
 
-
 static void
 update_file_timestamp (const char *path)
 {
@@ -1072,7 +1074,7 @@ save_file (SoupSession *session,
         GrRecipeStore *self = data;
         const char *cache_dir;
         g_autofree char *filename = NULL;
-        const char *argv[5];
+        const char *argv[6];
         g_autofree char *cmdline = NULL;
         g_autoptr(GSubprocess) subprocess = NULL;
         g_autoptr(GSubprocessLauncher) launcher = NULL;
@@ -1109,7 +1111,8 @@ save_file (SoupSession *session,
         argv[1] = "-xf";
         argv[2] = "data.tar.gz";
         argv[3] = "--overwrite";
-        argv[4] = NULL;
+        argv[4] = "--touch";
+        argv[5] = NULL;
 
         // FIXME use libarchive instead
         g_debug ("Running %s", cmdline = g_strjoinv (" ", (char **)argv));
@@ -1595,8 +1598,14 @@ gr_recipe_store_get_all_ingredients (GrRecipeStore *self,
         GHashTable *ingreds;
         char **result;
         int i, j;
+        const char **names;
+        int len;
 
-        ingreds = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+        ingreds = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, NULL);
+        names = gr_ingredient_get_names (&len);
+        for (i = 0; i < len; i++) {
+                g_hash_table_add (ingreds, (char *)names[i]);
+        }
 
         g_hash_table_iter_init (&iter, self->recipes);
         while (g_hash_table_iter_next (&iter, NULL, (gpointer *)&recipe)) {
@@ -1628,49 +1637,6 @@ gr_recipe_store_get_all_ingredients (GrRecipeStore *self,
         return result;
 }
 
-static void
-strv_prepend (char       ***strv_in,
-              const char   *s)
-{
-        char **strv;
-        int length;
-        int i;
-
-        length = g_strv_length (*strv_in);
-        strv = g_new (char *, length + 2);
-        strv[0] = g_strdup (s);
-        for (i = 0; i < length; i++)
-                strv[i + 1] = (*strv_in)[i];
-        strv[length + 1] = NULL;
-
-        g_free (*strv_in);
-        *strv_in = strv;
-}
-
-static void
-strv_remove (char       ***strv_in,
-             const char   *s)
-{
-        int i, j;
-        char **strv;
-        int length;
-
-        length = g_strv_length (*strv_in);
-        strv = g_new (char *, length + 1);
-
-        for (i = 0, j = 0; i < length; i++) {
-                if (strcmp (strv[i], s) == 0) {
-                        g_free (strv[i]);
-                        continue;
-                }
-                strv[j++] = strv[i];
-        }
-        strv[j] = NULL;
-
-        g_free (*strv_in);
-        *strv_in = strv;
-}
-
 void
 gr_recipe_store_add_favorite (GrRecipeStore *self,
                               GrRecipe      *recipe)
