@@ -404,7 +404,7 @@ portal_available (GtkWindow  *window,
 
         if (strcmp (interface, "org.freedesktop.portal.FileChooser") == 0)
                 message1 = _("Missing the desktop portal needed to open files from inside a Flatpak sandbox.");
-        else if (strcmp (interface, "org.freedestkop.portal.Print") == 0)
+        else if (strcmp (interface, "org.freedesktop.portal.Print") == 0)
                 message1 = _("Missing the desktop portal needed to print from inside a Flatpak sandbox.");
         else if (strcmp (interface, "org.freedesktop.portal.OpenURI") == 0)
                 message1 = _("Missing the desktop portal needed to open URLs from inside a Flatpak sandbox.");
@@ -796,3 +796,45 @@ pixbuf_blur (GdkPixbuf *src, gint radius, gint iterations)
                 pixbuf_blur_private (src, tmp, radius, div_kernel_size);
 }
 
+void
+strv_prepend (char       ***strv_in,
+              const char   *s)
+{
+        char **strv;
+        int length;
+        int i;
+
+        length = g_strv_length (*strv_in);
+        strv = g_new (char *, length + 2);
+        strv[0] = g_strdup (s); 
+        for (i = 0; i < length; i++)
+                strv[i + 1] = (*strv_in)[i];
+        strv[length + 1] = NULL;
+
+        g_free (*strv_in);
+        *strv_in = strv;
+}
+
+void
+strv_remove (char       ***strv_in,
+             const char   *s)
+{
+        int i, j;
+        char **strv;
+        int length;
+
+        length = g_strv_length (*strv_in);
+        strv = g_new (char *, length + 1);
+
+        for (i = 0, j = 0; i < length; i++) {
+                if (strcmp ((*strv_in)[i], s) == 0) {
+                        g_free ((*strv_in)[i]);
+                        continue;
+                }
+                strv[j++] = (*strv_in)[i];
+        }
+        strv[j] = NULL;
+
+        g_free (*strv_in);
+        *strv_in = strv;
+}
