@@ -74,18 +74,24 @@ struct _GrWindow
         GtkWidget *cuisine_page;
         GtkWidget *image_page;
         GtkWidget *cooking_page;
+
         GtkWidget *undo_revealer;
         GtkWidget *undo_label;
         GrRecipe  *undo_recipe;
         guint undo_timeout_id;
+
         GtkWidget *remind_revealer;
         GtkWidget *remind_label;
         GrRecipe  *remind_recipe;
         guint remind_timeout_id;
+
         GtkWidget *shopping_added_revealer;
         guint shopping_timeout_id;
+
         GtkWidget *shopping_done_revealer;
         guint shopping_done_timeout_id;
+        GList *shopping_done_list;
+        char **removed_ingredients;
 
         GObject *file_chooser;
         GrRecipeImporter *importer;
@@ -544,6 +550,20 @@ gr_window_new (GrApp *app)
         return g_object_new (GR_TYPE_WINDOW, "application", app, NULL);
 }
 
+typedef struct {
+        GrRecipe *recipe;
+        int serves;
+} ShoppingListEntry;
+
+static void
+shopping_list_entry_free (gpointer data)
+{
+        ShoppingListEntry *entry = data;
+
+        g_object_unref (entry->recipe);
+        g_free (entry);
+}
+
 static void
 gr_window_finalize (GObject *object)
 {
@@ -569,6 +589,14 @@ gr_window_finalize (GObject *object)
                 self->shopping_timeout_id = 0;
         }
 
+        g_list_free_full (self->shopping_done_list, shopping_list_entry_free);
+        g_strfreev (self->removed_ingredients);
+
+        if (self->shopping_done_timeout_id) {
+                g_source_remove (self->shopping_done_timeout_id);
+                self->shopping_done_timeout_id = 0;
+        }
+
         g_list_free (self->dialogs);
 
         G_OBJECT_CLASS (gr_window_parent_class)->finalize (object);
@@ -735,6 +763,11 @@ close_shopping_done (GrWindow *window)
                 window->shopping_done_timeout_id = 0;
         }
 
+        g_list_free_full (window->shopping_done_list, shopping_list_entry_free);
+        window->shopping_done_list = NULL;
+        g_strfreev (window->removed_ingredients);
+        window->removed_ingredients = NULL;
+
         gtk_revealer_set_reveal_child (GTK_REVEALER (window->shopping_done_revealer), FALSE);
 }
 
@@ -748,6 +781,27 @@ shopping_done_timeout (gpointer data)
         return G_SOURCE_REMOVE;
 }
 
+static void
+back_to_shopping (GrWindow *window)
+{
+        GrRecipeStore *store;
+        GList *l;
+        int i;
+
+        store = gr_recipe_store_get ();
+
+        for (l = window->shopping_done_list; l; l = l->next) {
+                ShoppingListEntry *entry = l->data;
+                gr_recipe_store_add_to_shopping (store, entry->recipe, entry->serves);
+        }
+        for (i = 0; window->removed_ingredients && window->removed_ingredients[i]; i++) {
+                gr_recipe_store_remove_shopping_ingredient (store, window->removed_ingredients[i]);
+        }
+
+        close_shopping_done (window);
+        gr_window_show_shopping (window);
+}
+
 static void
 gr_window_offer_cooking (GrWindow *window)
 {
@@ -762,10 +816,14 @@ static void gr_window_show_transient_list (GrWindow   *window,
 static void
 done_shopping (GrWindow *window)
 {
-        GList *recipes;
+        GList *recipes, *l;
         GrRecipeStore *store;
+        const char **removed_ingredients;
 
-        recipes = gr_shopping_page_get_recipes (GR_SHOPPING_PAGE (window->shopping_page));
+        store = gr_recipe_store_get ();
+
+        recipes = gr_recipe_store_get_shopping_list (store);
+        removed_ingredients = gr_recipe_store_get_removed_shopping_ingredients (store);
 
         if (recipes->next == NULL)
                 gr_window_show_recipe (window, recipes->data);
@@ -774,9 +832,23 @@ done_shopping (GrWindow *window)
 
         gr_window_offer_cooking (window);
 
+        g_list_free_full (window->shopping_done_list, shopping_list_entry_free);
+        window->shopping_done_list = NULL;
+
+        for (l = recipes; l; l = l->next) {
+                GrRecipe *recipe = l->data;
+                ShoppingListEntry *entry;
+
+                entry = g_new (ShoppingListEntry, 1);
+                entry->recipe = g_object_ref (recipe);
+                entry->serves = gr_recipe_store_get_shopping_serves (store, recipe);
+                window->shopping_done_list = g_list_append (window->shopping_done_list, entry);
+        }
         g_list_free_full (recipes, g_object_unref);
 
-        store = gr_recipe_store_get ();
+        g_strfreev (window->removed_ingredients);
+        window->removed_ingredients = g_strdupv ((char **)removed_ingredients);
+
         gr_recipe_store_clear_shopping_list (store);
 }
 
@@ -855,6 +927,7 @@ gr_window_class_init (GrWindowClass *klass)
         gtk_widget_class_bind_template_callback (widget_class, shopping_title_changed);
         gtk_widget_class_bind_template_callback (widget_class, done_shopping);
         gtk_widget_class_bind_template_callback (widget_class, close_shopping_done);
+        gtk_widget_class_bind_template_callback (widget_class, back_to_shopping);
         gtk_widget_class_bind_template_callback (widget_class, make_save_sensitive);
 }
 
@@ -1023,7 +1096,7 @@ present_my_chef_dialog (GrChef   *chef,
         GrWindow *window = data;
 
         window->chef_dialog = (GtkWidget *)gr_chef_dialog_new (chef, FALSE);
-        gtk_window_set_title (GTK_WINDOW (window->chef_dialog), _("My Chef Information"));
+        gtk_window_set_title (GTK_WINDOW (window->chef_dialog), _("Chef Information"));
         g_signal_connect (window->chef_dialog, "done", G_CALLBACK (chef_done), window);
         gr_window_present_dialog (window, GTK_WINDOW (window->chef_dialog));
 }
@@ -1049,6 +1122,10 @@ gr_window_load_recipe (GrWindow *window,
         if (window->file_chooser)
                 return;
 
+        if (in_flatpak_sandbox () &&
+            !portal_available (GTK_WINDOW (window), "org.freedesktop.portal.FileChooser"))
+                return;
+
         window->file_chooser = (GObject *)gtk_file_chooser_native_new (_("Select a recipe file"),
                                                                        GTK_WINDOW (window),
                                                                        GTK_FILE_CHOOSER_ACTION_OPEN,
@@ -1265,8 +1342,8 @@ gr_window_show_shopping (GrWindow *window)
 }
 
 static void
-do_show_myself (GrChef   *chef,
-                gpointer  data)
+do_show_mine (GrChef   *chef,
+              gpointer  data)
 {
         GrWindow *window = data;
 
@@ -1284,9 +1361,9 @@ do_show_myself (GrChef   *chef,
 }
 
 void
-gr_window_show_myself (GrWindow *window)
+gr_window_show_mine (GrWindow *window)
 {
-        gr_ensure_user_chef (GTK_WINDOW (window), do_show_myself, window);
+        gr_ensure_user_chef (GTK_WINDOW (window), do_show_mine, window);
 }
 
 void
@@ -1326,9 +1403,9 @@ gr_window_show_season (GrWindow   *window,
 }
 
 void
-gr_window_show_image (GrWindow *window,
-                      GArray   *images,
-                      int       index)
+gr_window_show_image (GrWindow  *window,
+                      GPtrArray *images,
+                      int        index)
 {
         if (images && images->len > 0) {
                 gr_image_page_set_images (GR_IMAGE_PAGE (window->image_page), images);
@@ -1405,6 +1482,66 @@ news_dialog_closed (GtkWidget *widget,
         return FALSE;
 }
 
+static GtkWidget *
+gr_release_info_new (const char *version,
+                     GDateTime  *date,
+                     const char *news)
+{
+        GtkWidget *box;
+        GtkWidget *heading;
+        GtkWidget *image;
+        GtkWidget *label;
+        GtkStyleContext *context;
+        g_autofree char *title = NULL;
+
+        box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
+
+        heading = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
+        gtk_widget_set_halign (heading, GTK_ALIGN_CENTER);
+        image = gtk_image_new_from_icon_name ("org.gnome.Recipes-symbolic", 1);
+        gtk_image_set_pixel_size (GTK_IMAGE (image), 32);
+        gtk_container_add (GTK_CONTAINER (heading), image);
+        /* TRANSLATORS: %s gets replaced by a version number */
+        title = g_strdup_printf (_("Recipes %s"), version);
+        label = gtk_label_new (title);
+        gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+        context = gtk_widget_get_style_context (label);
+        gtk_style_context_add_class (context, "heading");
+        gtk_style_context_add_class (context, "welcome");
+        gtk_container_add (GTK_CONTAINER (heading), label);
+        gtk_container_add (GTK_CONTAINER (box), heading);
+
+        if (date) {
+                g_autofree char *formatted = NULL;
+                g_autofree char *release = NULL;
+
+                formatted = g_date_time_format (date, "%F");
+                /* TRANSLATORS: %s gets replaced by a date */
+                release = g_strdup_printf (_("Released: %s"), formatted);
+                label = gtk_label_new (release);
+                gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+                gtk_container_add (GTK_CONTAINER (box), label);
+        }
+
+        if (news) {
+                g_auto(GStrv) para = NULL;
+                int i;
+
+                para = g_strsplit (news, "\n\n", -1);
+
+                for (i = 0; para[i]; i++) {
+                        label = gtk_label_new (para[i]);
+                        gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+                        gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+                        gtk_label_set_max_width_chars (GTK_LABEL (label), 55);
+                        gtk_label_set_width_chars (GTK_LABEL (label), 55);
+                        gtk_container_add (GTK_CONTAINER (box), label);
+                }
+        }
+
+        return box;
+}
+
 void
 gr_window_show_news (GrWindow *window)
 {
@@ -1417,7 +1554,7 @@ gr_window_show_news (GrWindow *window)
         if (window->news_dialog)
                 return;
 
-        news = get_release_info (PACKAGE_VERSION, "0.0.0");
+        news = get_release_info (PACKAGE_VERSION, "1.0.0");
         if (news->len == 0)
                 return;
 
@@ -1435,47 +1572,10 @@ gr_window_show_news (GrWindow *window)
 
         for (i = 0; i < news->len; i++) {
                 ReleaseInfo *ri = g_ptr_array_index (news, i);
-                GtkWidget *heading;
-                GtkWidget *image;
-                GtkWidget *label;
-                GtkStyleContext *context;
-                g_autofree char *title = NULL;
+                GtkWidget *info;
 
-                heading = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
-                gtk_widget_set_halign (heading, GTK_ALIGN_CENTER);
-                image = gtk_image_new_from_icon_name ("org.gnome.Recipes-symbolic", 1);
-                gtk_image_set_pixel_size (GTK_IMAGE (image), 32);
-                gtk_container_add (GTK_CONTAINER (heading), image);
-                /* TRANSLATORS: %s gets replaced by a version number */
-                title = g_strdup_printf (_("Recipes %s"), ri->version);
-                label = gtk_label_new (title);
-                gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-                context = gtk_widget_get_style_context (label);
-                gtk_style_context_add_class (context, "heading");
-                gtk_style_context_add_class (context, "welcome");
-                gtk_container_add (GTK_CONTAINER (heading), label);
-                gtk_container_add (GTK_CONTAINER (box), heading);
-
-                if (ri->date) {
-                        g_autofree char *date = NULL;
-                        g_autofree char *release = NULL;
-
-                        date = g_date_time_format (ri->date, "%F");
-                        /* TRANSLATORS: %s gets replaced by a date */
-                        release = g_strdup_printf (_("Released: %s"), date);
-                        label = gtk_label_new (release);
-                        gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-                        gtk_container_add (GTK_CONTAINER (box), label);
-                }
-
-                if (ri->news) {
-                        label = gtk_label_new (ri->news->str);
-                        gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-                        gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-                        gtk_label_set_max_width_chars (GTK_LABEL (label), 55);
-                        gtk_label_set_width_chars (GTK_LABEL (label), 55);
-                        gtk_container_add (GTK_CONTAINER (box), label);
-                }
+                info = gr_release_info_new (ri->version, ri->date, ri->news->str);
+                gtk_container_add (GTK_CONTAINER (box), info);
         }
 
         gtk_widget_show_all (box);
@@ -1487,9 +1587,10 @@ void
 gr_window_show_report_issue (GrWindow *window)
 {
         const char *uri = "https://bugzilla.gnome.org/enter_bug.cgi?product=recipes";
-        g_autoptr(GError) error = NULL;
 
-        gtk_show_uri_on_window (GTK_WINDOW (window), uri, GDK_CURRENT_TIME, &error);
-        if (error)
-                g_warning ("Unable to show '%s': %s", uri, error->message);
+        if (in_flatpak_sandbox () &&
+            !portal_available (GTK_WINDOW (window), "org.freedesktop.portal.OpenURI"))
+                return;
+
+        gtk_show_uri_on_window (GTK_WINDOW (window), uri, GDK_CURRENT_TIME, NULL);
 }
